# Copyright (c) 2025 StackHPC Ltd.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

import os
import tempfile

from ansible.module_utils.common.text.converters import to_bytes
from ansible.plugins.action.template import ActionModule as TemplateBase

from ansible import errors as ansible_errors


class ActionModule(TemplateBase):
    """Decorates template action to support using content parameter"""

    def run(self, *args, **kwargs):
        module_args = self._task.args
        if "src" in module_args and "content" in module_args:
            raise ansible_errors.AnsibleActionFail(
                "Invalid argument: content and src are mutually exclusive."
            )
        if "content" not in module_args and "src" not in module_args:
            raise ansible_errors.AnsibleActionFail(
                "Invalid argument: You must speicfy either content or src"
            )

        if "src" in module_args:
            return super().run(*args, **kwargs)

        with tempfile.NamedTemporaryFile() as fp:
            content = module_args.pop("content", "")
            fp.write(to_bytes(content))
            fp.flush()
            tempfile_path = os.path.join(tempfile.gettempdir(), str(fp.name))
            module_args["src"] = tempfile_path
            return super().run(*args, **kwargs)



# Copyright (c) 2017 StackHPC Ltd.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.


def is_in(item, container):
    """Tests whether an item is in a container (e.g. a list)."""
    return item in container


class TestModule(object):
    """'Functional' programming tests."""

    def tests(self):
        return {
            'is_in': is_in,
        }



from ansible.plugins.action import ActionBase

_engine_to_module = {
   'docker': 'community.docker.docker_login',
   'podman': 'containers.podman.podman_login'
}

class ActionModule(ActionBase):
    def run(self, tmp=None, task_vars=None):
        super(ActionModule, self).run(tmp, task_vars)
        module_args = self._task.args.copy()
        engine = task_vars.get("container_engine", "docker")
        module = _engine_to_module.get(engine)
        if engine == "podman":
            # Drop unspported arguments
            module_args.pop("reauthorize", None)
            # Rename arguments that differ from docker
            if module_args.get("registry_url"):
                module_args["registry"] = module_args["registry_url"]
                del module_args["registry_url"]
        module_return = self._execute_module(module_name=module,
                                             module_args=module_args,
                                             task_vars=task_vars, tmp=tmp)
        return module_return



from ansible.errors import AnsibleError
from ansible.plugins.action import ActionBase

_engine_to_module = {
   'docker': 'community.docker.docker_image',
   'podman': 'containers.podman.podman_image'
}

class ActionModule(ActionBase):
    def run(self, tmp=None, task_vars=None):
        super(ActionModule, self).run(tmp, task_vars)
        module_args = self._task.args.copy()
        engine = task_vars.get("container_engine", "docker")
        if engine == "podman":
            # Translate from docker args
            source = module_args["source"]
            if source == "build":
                module_args["state"] = "build"
            elif source == "pull":
                module_args["pull"] = True
            else:
                raise AnsibleError(f'Unsupported source parameter: {source}')
            del module_args["source"]
        module = _engine_to_module.get(engine)
        module_return = self._execute_module(module_name=module,
                                             module_args=module_args,
                                             task_vars=task_vars, tmp=tmp)
        return module_return



from ansible.plugins.action import ActionBase

_engine_to_module = {
   'docker': 'community.docker.docker_volume',
   'podman': 'containers.podman.podman_volume'
}

class ActionModule(ActionBase):
    def run(self, tmp=None, task_vars=None):
        super(ActionModule, self).run(tmp, task_vars)
        module_args = self._task.args.copy()
        engine = task_vars.get("container_engine", "docker")
        module = _engine_to_module.get(engine)
        module_return = self._execute_module(module_name=module,
                                             module_args=module_args,
                                             task_vars=task_vars, tmp=tmp)
        return module_return
